(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react')) :
  typeof define === 'function' && define.amd ? define(['exports', 'react'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['feature-flags-react'] = {}, global.react));
}(this, (function (exports, react) { 'use strict';

  const post = async (url, token, body) => {
    const response = await fetch(url, {
      method: 'POST',
      headers: {
        Authorization: token,
        'Content-Type': 'application/json',
        Accept: '*/*'
      },
      body: JSON.stringify(body),
      cache: 'no-cache'
    });

    if (response.ok) {
      const jsonResponse = await response.json();
      return jsonResponse;
    }

    throw new Error(`HTTP Error ${response.status}`);
  };

  class FlagsClient {
    async getFlag(key, context) {
      return post(`${this.serviceUrl}/flags/${key}`, this.clientToken, context);
    }

    setup(serviceUrl, clientToken) {
      this.serviceUrl = serviceUrl;
      this.clientToken = clientToken;
    }

  }

  var Client = new FlagsClient();

  const useFlag = (key, clientId, context) => {
    const [flagState, setFlagState] = react.useState({
      flag: null,
      error: null,
      loading: true
    });
    react.useEffect(() => {
      const getFlag = async () => {
        try {
          const flag = await Client.getFlag(key, { ...context,
            clientId
          });
          setFlagState({
            flag,
            error: null,
            loading: false
          });
        } catch (error) {
          setFlagState({
            error: error.message,
            flag: null,
            loading: false
          });
        }
      };

      getFlag();
    }, [key, context, setFlagState]);
    return flagState;
  };
  const useLazyFlag = () => {
    const [flagState, setFlagState] = react.useState({
      flag: null,
      error: null,
      loading: false
    });
    const getFlag = react.useCallback(async (key, clientId, context) => {
      try {
        setFlagState({
          flag: null,
          error: null,
          loading: true
        });
        const flag = await Client.getFlag(key, { ...context,
          clientId
        });
        setFlagState({
          flag,
          error: null,
          loading: false
        });
      } catch (error) {
        setFlagState({
          error: error.message,
          flag: null,
          loading: false
        });
      }
    }, []);
    return [flagState, getFlag];
  };
  const useSetupClient = (serviceUrl, clientKey) => {
    react.useEffect(() => {
      Client.setup(serviceUrl, clientKey);
    }, [serviceUrl, clientKey]);
  };
  const FlagsClient$1 = Client;

  exports.FlagsClient = FlagsClient$1;
  exports.useFlag = useFlag;
  exports.useLazyFlag = useLazyFlag;
  exports.useSetupClient = useSetupClient;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
